changeset 2824:5389a40f3566

Backed out changeset 4151640654ae I'm not sure if this is a good idea.
author William Pitcock <nenolod@atheme.org>
date Sun, 13 Jul 2008 15:17:16 -0500
parents 4151640654ae
children 9cdd04a31ab2
files src/madplug/plugin.c
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/madplug/plugin.c	Sun Jul 13 15:54:39 2008 +0200
+++ b/src/madplug/plugin.c	Sun Jul 13 15:17:16 2008 -0500
@@ -488,8 +488,8 @@
             }
             break;
         }
-    } while (state != STATE_FATAL && tries < 256);
-    /* Give up after 256 failed resync attempts or fatal errors */
+    } while (state != STATE_FATAL && tries < 16);
+    /* Give up after 16 failed resync attempts or fatal errors */
 
     g_message("Rejecting %s (not an MP3 file?)", filename);
     return 0;